.. _{doc_ref}:

{new_version}
{title_marker}

*{release_date}*

.. todo: add description for this release.

Get and install
---------------

From PyPI::

    pip install nitrate-tcms

From image registry::

    docker pull quay.io/nitrate/nitrate:{new_version}

Refer to :ref:`how_to_run` for details of installation.

Database Migration
------------------

.. todo: is there database migration?

Change Log
----------

{change_logs}
